import * as React from 'react';

import {
    Toolbar,
    Inspector,
    Graph,
    TreeFilter,
    InvalidNodeTypes,
    LoadingIndicator,
    SearchBox,
    NodeTypeCounter,
    NodeTypeExportButton,
} from './index';
import { AppTheme, createUseAppStyles } from '../core';
import { NodeTypeTree } from './NodeTypeTree';
import { ReactElement } from 'react';

const useStyles = createUseAppStyles((theme: AppTheme) => ({
    app: {
        display: 'grid',
        height: 'inherit',
        gridGap: theme.spacing.full,
        gridTemplateAreas: `"left main right"`,
        gridTemplateColumns: `${theme.size.sidebarWidth} 1fr ${theme.size.sidebarWidth}`,
        '& svg.neos-svg-inline--fa': {
            width: '14px',
            height: '14px',
            alignSelf: 'center',
        },
    },
    left: {
        gridArea: 'left',
        maxHeight: 'inherit',
        overflow: 'auto',
    },
    main: {
        gridArea: 'main',
        display: 'flex',
        flexDirection: 'column',
    },
    right: {
        gridArea: 'right',
        maxHeight: 'inherit',
        overflow: 'auto',
    },
}));

const GraphApp: React.FC = (): ReactElement => {
    const classes = useStyles();

    return (
        <div className={classes.app}>
            <LoadingIndicator />
            <div className={classes.left}>
                <TreeFilter />
                <SearchBox />
                <NodeTypeTree />
                <InvalidNodeTypes />
                <NodeTypeCounter />
                <NodeTypeExportButton />
            </div>
            <div className={classes.main}>
                <Toolbar />
                <Graph />
            </div>
            <div className={classes.right}>
                <Inspector />
            </div>
        </div>
    );
};
export default React.memo(GraphApp);
